package com.nisum.order_producer.controller;

import com.nisum.order_producer.dto.OrderDto;
import com.nisum.order_producer.entity.Order;
import com.nisum.order_producer.service.OrderProducerService;
import jakarta.validation.Valid;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("/orderProducer")
public class OrderProducerController {

    @Autowired
    private OrderProducerService orderProducerService;

    private static final Logger logger = LoggerFactory.getLogger(OrderProducerController.class);

    @PostMapping("/addOrder")
    public Mono<ResponseEntity<Order>> addOrder(@Valid @RequestBody Mono<Order> orderInfo) {


        logger.info("Received request to add a new order : ");
        return orderInfo
                .flatMap(order -> {
                    logger.info("Processing order: {}", orderInfo);
                    return orderProducerService.saveOrder(order);
                })
                .map(savedOrder -> {
                    logger.info("Successfully saved order: {}");
                    return ResponseEntity.ok(savedOrder);
                })
                .doOnError(error -> logger.error("Error while saving order:"))
                .defaultIfEmpty(ResponseEntity.badRequest().build());


    }

    /*public Mono<ResponseEntity<OrderDto>> addProduct(@Valid @RequestBody Mono<OrderDto> orderMono) {
        logger.info("Received request to add a new order");

        return orderMono
                .flatMap(order -> {
                    logger.info("Processing order: {}", order);
                    return orderProducerService.saveOrder(order);
                })
                .map(savedOrder -> {
                    logger.info("Successfully saved order: {}", savedOrder);
                    return ResponseEntity.ok(savedOrder);
                })
                .doOnError(error -> logger.error("Error while saving order: {}", error.getMessage()));

    }*/


    @GetMapping("/findAllOrders")
    public ResponseEntity<Flux<Order>> findAllOrders(){
        logger.info("Received request to fetch all orders");
        Flux<Order> orders = orderProducerService.getAllOrder();
        return ResponseEntity.ok(orders);
    }

    @GetMapping("/findOrderById/{id}")
    public Mono<ResponseEntity<Order>> findOrderById(@PathVariable String id){
        logger.info("Fetching order with ID: {}", id);
        return orderProducerService.getByOrderId(id)
                .map(orderDto -> {
                    logger.info("Order found: {}", orderDto);
                    return ResponseEntity.ok(orderDto);
                })
                .doOnError(error -> logger.error("Error fetching order: {}", error.getMessage()))
                .defaultIfEmpty(ResponseEntity.notFound().build());
    }


}
