package com.nisum.order_producer.entity;

import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Size;
import lombok.*;
import org.springframework.data.mongodb.core.mapping.Document;
import java.time.LocalDateTime;
import java.util.List;

@Document(collection = "order_producer")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Setter
@Getter
public class Order {


    private String orderId;
    @NotNull(message = "Customer ID cannot be null")
    @NotEmpty(message = "Customer ID cannot be empty")
    private String customerId;
    @NotNull(message = "Items cannot be null")
    @Size(min = 1, message = "Order must contain at least one item")
    private List<Item> items;
    private LocalDateTime createdDate;
    private LocalDateTime modifiedDate;

    @NotNull(message = "Modified by cannot be null")
    @NotEmpty(message = "Modified by cannot be empty")
    private String modifiedBy;
    @NotNull(message = "Created by cannot be null")
    @NotEmpty(message = "Created by cannot be empty")
    private String createdBy;

    @Override
    public String toString() {
        return "Order{" +
                "orderId='" + orderId + '\'' +
                ", customerId='" + customerId + '\'' +
                ", items=" + items +
                ", createdDate=" + createdDate +
                ", modifiedDate=" + modifiedDate +
                ", modifiedBy='" + modifiedBy + '\'' +
                ", createdBy='" + createdBy + '\'' +
                '}';
    }
}
